Here is the bulk of the sanitizing.
Almost all occurrences of "bytecode" in the sources have been eliminated.


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@37913 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/tools/llvm-prof/llvm-prof.cpp b/tools/llvm-prof/llvm-prof.cpp
index c85b0da..dcb9d1f 100644
--- a/tools/llvm-prof/llvm-prof.cpp
+++ b/tools/llvm-prof/llvm-prof.cpp
@@ -32,8 +32,8 @@
 
 namespace {
   cl::opt<std::string>
-  BytecodeFile(cl::Positional, cl::desc("<program bytecode file>"),
-               cl::Required);
+  BitcodeFile(cl::Positional, cl::desc("<program bitcode file>"),
+              cl::Required);
 
   cl::opt<std::string>
   ProfileDataFile(cl::Positional, cl::desc("<llvmprof.out file>"),
@@ -115,16 +115,16 @@
     cl::ParseCommandLineOptions(argc, argv, " llvm profile dump decoder\n");
     sys::PrintStackTraceOnErrorSignal();
 
     // Read in the bytecode file...
     std::string ErrorMessage;
     Module *M = 0;
-    if (MemoryBuffer *Buffer = MemoryBuffer::getFileOrSTDIN(BytecodeFile,
+    if (MemoryBuffer *Buffer = MemoryBuffer::getFileOrSTDIN(BitcodeFile,
                                                             &ErrorMessage)) {
       M = ParseBitcodeFile(Buffer, &ErrorMessage);
       delete Buffer;
     }
     if (M == 0) {
-      std::cerr << argv[0] << ": " << BytecodeFile << ": " 
+      std::cerr << argv[0] << ": " << BitcodeFile << ": " 
         << ErrorMessage << "\n";
       return 1;
     }
@@ -115,16 +115,16 @@
     sys::PrintStackTraceOnErrorSignal();
 
-    // Read in the bytecode file...
+    // Read in the bitcode file...
     std::string ErrorMessage;
     Module *M = 0;